summaryrefslogtreecommitdiffstats
path: root/kdat/FileInfoWidget.h
diff options
context:
space:
mode:
Diffstat (limited to 'kdat/FileInfoWidget.h')
-rw-r--r--kdat/FileInfoWidget.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kdat/FileInfoWidget.h b/kdat/FileInfoWidget.h
index 5e7f9e2..0a36f61 100644
--- a/kdat/FileInfoWidget.h
+++ b/kdat/FileInfoWidget.h
@@ -40,10 +40,10 @@ public:
/**
* Create a new file info widget.
*
* @param tqparent The tqparent widget.
* @param name The name of this widget.
*/
- FileInfoWidget( TQWidget* tqparent = 0, const char* name = 0 );
+ FileInfoWidget( TQWidget* parent = 0, const char* name = 0 );
/**
* Destroy the file info widget.
@@ -40,10 +40,10 @@ public:
* Create a new file info widget.
*
- * @param tqparent The tqparent widget.
+ * @param parent The parent widget.
* @param name The name of this widget.
*/